==> jc-1.4.0.tar.gz: java/util/Collections__24ReverseComparator.c <==
// final class java.util.Collections$ReverseComparator

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class d1282e171465288b java_lang_Comparable
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 9574af3fed58029a java_util_Collections
// @dep_class 16e4449bbde9c097 java_util_Collections__24ReverseComparator
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_Comparable
// @dep_header java_lang_String
// @dep_header java_util_Collections
// @dep_header java_util_Collections__24ReverseComparator
// @dep_header java_util_Comparator

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/Comparable.h"
#include "java/lang/String.h"
#include "java/util/Collections.h"
#include "java/util/Collections__24ReverseComparator.h"
#include "java/util/Comparator.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_java_util_Collections__24ReverseComparator$initial_value$serialVersionUID = _JC_JLONG(7207038068494060240);
static _jc_field _jc_java_util_Collections__24ReverseComparator$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_java_util_Collections__24ReverseComparator$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_util_Collections__24ReverseComparator$fields_struct, serialVersionUID),
	.initial_value=	&_jc_java_util_Collections__24ReverseComparator$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_java_util_Collections__24ReverseComparator$fields[] = {
	&_jc_java_util_Collections__24ReverseComparator$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_util_Collections__24ReverseComparator$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_util_Collections__24ReverseComparator$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_util_Collections__24ReverseComparator$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_util_Collections__24ReverseComparator$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__24ReverseComparator$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__24ReverseComparator$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__24ReverseComparator, _init$52f4ad9f2989aeee);

void
_jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_util_Collections__24ReverseComparator$object *this)
{
	struct _jc_java_util_Collections__24ReverseComparator$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(1187);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_java_util_Collections__24ReverseComparator$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_java_util_Collections__24ReverseComparator$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_java_util_Collections__24ReverseComparator$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_java_util_Collections__24ReverseComparator$type,
	.param_types=		&_jc_java_util_Collections__24ReverseComparator$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__24ReverseComparator$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__24ReverseComparator$vtable, java_util_Collections__24ReverseComparator.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__24ReverseComparator$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__24ReverseComparator, compare$ef65339aa5f9531b);

jint
_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_java_util_Collections__24ReverseComparator$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	jint i0;
	struct _jc_java_util_Collections__24ReverseComparator$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(1198);				// 0
	r3 = _JC_CAST(env, &_jc_java_lang_Comparable$type, r2);
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x84fc6fc4a23c98a3), jint, r1);
	return i0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_util_Collections__24ReverseComparator$methods[] = {
	&_jc_java_util_Collections__24ReverseComparator$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_java_util_Collections__24ReverseComparator$fields_struct _jc_java_util_Collections__24ReverseComparator$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$interfaces[] = {
	&_jc_java_util_Comparator$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_27[] = {
	&_jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_util_Collections__24ReverseComparator$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_1,
	[27]=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_java_util_Collections__24ReverseComparator$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_23[] = {
	&_jc_java_util_Collections__24ReverseComparator$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_23,
	[65]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_65,
	[113]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_113,
	[125]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_125
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_util_Collections__24ReverseComparator$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Comparable",	_JC_JLONG(0xd1282e171465288b) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Collections",	_JC_JLONG(0x9574af3fed58029a) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_util_Collections__24ReverseComparator$vtype _jc_java_util_Collections__24ReverseComparator$type = {
    .type= {
	.name=			"java/util/Collections$ReverseComparator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_util_Collections__24ReverseComparator$interfaces) / sizeof(*_jc_java_util_Collections__24ReverseComparator$interfaces),
	.interfaces=		_jc_java_util_Collections__24ReverseComparator$interfaces,
	.imethod_hash_table=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_table,
	.imethod_quick_table=	_jc_java_util_Collections__24ReverseComparator$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x16e4449bbde9c097),
		.source_file=		"Collections.java",
		.instance_size=		sizeof(_jc_java_util_Collections__24ReverseComparator$refs) + sizeof(_jc_java_util_Collections__24ReverseComparator$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_java_util_Collections__24ReverseComparator$fields) / sizeof(*_jc_java_util_Collections__24ReverseComparator$fields),
		.fields=		_jc_java_util_Collections__24ReverseComparator$fields,
		.num_methods=		sizeof(_jc_java_util_Collections__24ReverseComparator$methods) / sizeof(*_jc_java_util_Collections__24ReverseComparator$methods),
		.methods=		_jc_java_util_Collections__24ReverseComparator$methods,
		.instanceof_hash_table=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_table,
		.class_fields=		&_jc_java_util_Collections__24ReverseComparator$class_fields,
		.outer_class=		&_jc_java_util_Collections$type,
		.num_class_depends=		sizeof(_jc_java_util_Collections__24ReverseComparator$class_depends) / sizeof(*_jc_java_util_Collections__24ReverseComparator$class_depends),
		.class_depends=		_jc_java_util_Collections__24ReverseComparator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_Collections__24ReverseComparator= {
	    .compare$ef65339aa5f9531b=
		&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b,
	},
    }
};

==> jc-1.4.5.tar.gz: java/util/Collections__24ReverseComparator.c <==
// final class java.util.Collections$ReverseComparator

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class d1282e171465288b java_lang_Comparable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 9574af3fed58029a java_util_Collections
// @dep_class 16e4449bbde9c097 java_util_Collections__24ReverseComparator
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_Comparable
// @dep_header java_lang_String
// @dep_header java_util_Collections
// @dep_header java_util_Collections__24ReverseComparator
// @dep_header java_util_Comparator

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/Comparable.h"
#include "java/lang/String.h"
#include "java/util/Collections.h"
#include "java/util/Collections__24ReverseComparator.h"
#include "java/util/Comparator.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_java_util_Collections__24ReverseComparator$initial_value$serialVersionUID = _JC_JLONG(7207038068494060240);
static _jc_field _jc_java_util_Collections__24ReverseComparator$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_java_util_Collections__24ReverseComparator$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_util_Collections__24ReverseComparator$fields_struct, serialVersionUID),
	.initial_value=	&_jc_java_util_Collections__24ReverseComparator$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_java_util_Collections__24ReverseComparator$fields[] = {
	&_jc_java_util_Collections__24ReverseComparator$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_util_Collections__24ReverseComparator$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_util_Collections__24ReverseComparator$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_util_Collections__24ReverseComparator$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_util_Collections__24ReverseComparator$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__24ReverseComparator$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__24ReverseComparator$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__24ReverseComparator, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_util_Collections__24ReverseComparator$object *this)
{
	struct _jc_java_util_Collections__24ReverseComparator$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(1187);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_java_util_Collections__24ReverseComparator$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_java_util_Collections__24ReverseComparator$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_java_util_Collections__24ReverseComparator$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_java_util_Collections__24ReverseComparator$type,
	.param_types=		&_jc_java_util_Collections__24ReverseComparator$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__24ReverseComparator$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__24ReverseComparator$vtable, java_util_Collections__24ReverseComparator.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__24ReverseComparator$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__24ReverseComparator, compare$ef65339aa5f9531b);

jint _JC_JCNI_ATTR
_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_java_util_Collections__24ReverseComparator$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	jint i0;
	struct _jc_java_util_Collections__24ReverseComparator$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(1198);				// 0
	r3 = _JC_CAST(env, &_jc_java_lang_Comparable$type, r2);
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x84fc6fc4a23c98a3), jint, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r1);
	return i0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_util_Collections__24ReverseComparator$methods[] = {
	&_jc_java_util_Collections__24ReverseComparator$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_java_util_Collections__24ReverseComparator$fields_struct _jc_java_util_Collections__24ReverseComparator$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$interfaces[] = {
	&_jc_java_util_Comparator$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_27[] = {
	&_jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_util_Collections__24ReverseComparator$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_1,
	[27]=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_java_util_Collections__24ReverseComparator$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_23[] = {
	&_jc_java_util_Collections__24ReverseComparator$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_util_Collections__24ReverseComparator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_23,
	[65]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_65,
	[101]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_101,
	[125]=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_bucket_125
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_util_Collections__24ReverseComparator$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Comparable",	_JC_JLONG(0xd1282e171465288b) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Collections",	_JC_JLONG(0x9574af3fed58029a) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_util_Collections__24ReverseComparator$vtype _jc_java_util_Collections__24ReverseComparator$type = {
    .type= {
	.name=			"java/util/Collections$ReverseComparator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_util_Collections__24ReverseComparator$interfaces) / sizeof(*_jc_java_util_Collections__24ReverseComparator$interfaces),
	.interfaces=		_jc_java_util_Collections__24ReverseComparator$interfaces,
	.imethod_hash_table=	_jc_java_util_Collections__24ReverseComparator$imethod_hash_table,
	.imethod_quick_table=	_jc_java_util_Collections__24ReverseComparator$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x16e4449bbde9c097),
		.source_file=		"Collections.java",
		.instance_size=		sizeof(_jc_java_util_Collections__24ReverseComparator$refs) + sizeof(_jc_java_util_Collections__24ReverseComparator$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_java_util_Collections__24ReverseComparator$fields) / sizeof(*_jc_java_util_Collections__24ReverseComparator$fields),
		.fields=		_jc_java_util_Collections__24ReverseComparator$fields,
		.num_methods=		sizeof(_jc_java_util_Collections__24ReverseComparator$methods) / sizeof(*_jc_java_util_Collections__24ReverseComparator$methods),
		.methods=		_jc_java_util_Collections__24ReverseComparator$methods,
		.instanceof_hash_table=	_jc_java_util_Collections__24ReverseComparator$instanceof_hash_table,
		.class_fields=		&_jc_java_util_Collections__24ReverseComparator$class_fields,
		.outer_class=		&_jc_java_util_Collections$type,
		.num_class_depends=		sizeof(_jc_java_util_Collections__24ReverseComparator$class_depends) / sizeof(*_jc_java_util_Collections__24ReverseComparator$class_depends),
		.class_depends=		_jc_java_util_Collections__24ReverseComparator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_Collections__24ReverseComparator= {
	    .compare$ef65339aa5f9531b=
		&_jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b,
	},
    }
};
